package Translational

	/**************
	 *            *
	 * CONECTORES *
	 *            *
	 **************/
	connector Flange_a "(left) 1D translational flange (flange axis directed INTO cut plane, e. g. from left to right)"
		Real s "absolute position of flange";
		flow Real f "cut force directed into flange";
	end Flange_a;
	
	
	connector Flange_b "right 1D translational flange (flange axis directed OUT OF cut plane)" 
		Real s "absolute position of flange";
		flow Real f "cut force directed into flange";
	end Flange_b;
	
	
	
 	/**************
	 *            *
	 *   FIXED    *
	 *            *
	 **************/
	model Fixed "Fixed flange"
      parameter Real s0=0 "fixed offset position of housing";
		
      Flange_b flange_b;
		
    equation
      flange.s = s0;
   end Fixed;
	
	
	
	/***************
	 *             *
	 * SLIDINGMASS *
	 *             *
	 ***************/
	model SlidingMass "Sliding Mass with inertia"
		parameter Real m=1 "mass of the sliding mass";
		parameter Real L=0 "Length of component, from left flange to right flange (= flange_b.s - flange_a.s)";
		
		Flange_a flange_a "Left flange of translational component" ;		  
		Flange_b flange_b "Right flange of translational component";
         
		Real s(start=0) "Absolute position of center of component (s = flange_a.s + L/2 = flange_b.s - L/2)";
		Real v(start=0) "absolute velocity of component";
		Real a(start=0) "absolute acceleration of component";

   equation
		flange_a.s = s - L/2;
		flange_b.s = s + L/2;
		v = der(s);
		a = der(v);
		m*a = flange_a.f + flange_b.f;
   end SlidingMass;
	
	
	
	/***************
	 *             *
	 *   SPRING    *
	 *             *
	 ***************/ 
	model Spring "Linear 1D translational spring"
		
		Flange_a flange_a "Left flange of compliant 1-dim. translational component";
		Flange_b flange_b "Right flange of compliant 1-dim. translational component"; 
        		  
		Real s_rel(start=0) "relative distance (= flange_b.s - flange_a.s)";
		Real f "force between flanges (positive in direction of flange axis R)";
		
		parameter Real c=1 "spring constant ";
		parameter Real s_rel0=0 "unstretched spring length";


   equation
	   s_rel = flange_b.s - flange_a.s;
      flange_b.f = f;
      flange_a.f = -f;
      f = c*(s_rel - s_rel0);
   end Spring;



	/***************
	 *             *
	 *    DAMPER   *
	 *             *
	 ***************/
	model Damper "Linear 1D translational damper"
		parameter Real s_nominal=1e-4 "Nominal value of s_rel (used for scaling)";
		parameter Real d=0 "damping constant";

		Real s_rel(start=0) "Relative distance (= flange_b.s - flange_a.s)";
		Real v_rel(start=0) "Relative velocity (= der(s_rel))";
		Real f "Forces between flanges (= flange_b.f)";
      
		Flange_a flange_a "Left flange of compliant 1-dim. translational component";
		Flange_b flange_b "Right flange of compliant 1-dim. transational component"; 
		  
   equation
		s_rel = flange_b.s - flange_a.s;
		v_rel = der(s_rel);
		flange_b.f =  f;
		flange_a.f = -f;
		f = d*v_rel;
   end Damper;
	

	/****************
	 *              *
	 * SPRINGDAMPER *
	 *              *
	 ****************/
	model SpringDamper "Linear 1D translational spring and damper in parallel"
		parameter Real s_nominal=1e-4 "Nominal value of s_rel (used for scaling)";

		Real s_rel(start=0) "Relative distance (= flange_b.s - flange_a.s)";
		Real v_rel(start=0) "Relative velocity (= der(s_rel))";
		Real f "Forces between flanges (= flange_b.f)";
		
		Flange_a flange_a "Left flange of compliant 1-dim. translational component";				  
		Flange_b flange_b "Right flange of compliant 1-dim. transational component";
		
		parameter Real c= 1 "spring constant";
		parameter Real d= 1 "damping constant";
		parameter Real s_rel0=0 "unstretched spring length";
		
	equation
		s_rel = flange_b.s - flange_a.s;
		v_rel = der(s_rel);
		flange_b.f =  f;
		flange_a.f = -f;
		f = c*(s_rel - s_rel0) + d*v_rel;
   end SpringDamper;

	/****************
	 *              *
	 *    FORCE     *
	 *              *
	 ****************/
	model Force "External force acting on a drive train element as input signal"  
		Flange_b flange_b "Flange of component"; 
       
		parameter Real f0=1 "driving force as input signal" ;

    equation
		flange.f = -f0;
    end Force;

end Translational;